@@ -200,7 +200,7 @@ class Model(Writer):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        from project.settings import STATICFILES_DIRS
+        from projectsettings import STATICFILES_DIRS
 
         icons_path = [path for key, path in STATICFILES_DIRS if key == self.image_dir_name]
         if len(icons_path) != 1 or not os.path.exists(icons_path[0]):
