@@ -90,20 +90,10 @@ class Crypto_file(AuditModel):
         else:
             filename = attfile
 
-            if isinstance(settings.FILES_STORE, str):
-                _, exists = cls.exists(filename)
-                if exists is False or getsize(filename) == 0:
-                    logger.debug(f'file: {attfile} not exists')
-                    return filename, False
-
-            elif isinstance(settings.FILES_STORE, dict) and settings.FILES_STORE.get('mode') == SFTP:
-                ssh_client = settings.SSH_CLIENTS.client(settings.FILES_STORE)
-                res = ssh_client.exists(filename)
-                if res is False or ssh_client.getsize(filename) == 0:
-                    logger.debug(f'file: {attfile} not exists')
-                    return filename, False
-            else:
-                raise Exception(FILES_STORE_UNKNOWN_TYPE)
+            _, exists = cls.exists(filename)
+            if exists is False or getsize(filename) == 0:
+                logger.debug(f'file: {attfile} not exists')
+                return filename, False
 
             logger.debug(f'file: {attfile} exists')
             return filename, True
@@ -114,12 +104,7 @@ class Crypto_file(AuditModel):
         file_path = item.attfile.name
 
         if old_file_store:
-            if isinstance(settings.FILES_STORE, str):
-                file_path = file_path.replace(old_file_store, settings.FILES_STORE)
-            elif isinstance(settings.FILES_STORE, dict) and settings.FILES_STORE.get('mode') == SFTP:
-                file_path = file_path.replace(old_file_store, settings.FILES_STORE.get('PATH'))
-            else:
-                raise Exception(FILES_STORE_UNKNOWN_TYPE)
+            file_path = file_path.replace(old_file_store, settings.FILES_STORE)
 
         if isinstance(settings.REPLACE_FILE_PATH, dict):
             for key, value in settings.REPLACE_FILE_PATH.items():
@@ -129,10 +114,7 @@ class Crypto_file(AuditModel):
             if os.altsep:
                 file_path = file_path.replace(os.altsep, os.sep)
 
-            if isinstance(settings.FILES_STORE, str):
-                os.remove(file_path)
-            else:
-                settings.SSH_CLIENTS.client(settings.FILES_STORE).remove(settings.FILES_STORE.get('PATH'))
+            os.remove(file_path)
             logger.debug(f'Removed file: {file_path}')
 
     @classmethod
@@ -154,12 +136,8 @@ class Crypto_file(AuditModel):
 
         res = cls.objects.getOptional(real_name=uploadItemEx.real_file_name, size=uploadItemEx.file_size)
 
-        if isinstance(settings.FILES_STORE, dict):
-            if res is not None and str(res.attfile) != '' and settings.SSH_CLIENTS.client(settings.FILES_STORE).exists(str(res.attfile)):
-                return res, False
-        else:
-            if res is not None and str(res.attfile) != '' and os.path.exists(str(res.attfile)):
-                return res, False
+        if res is not None and str(res.attfile) != '' and os.path.exists(str(res.attfile)):
+            return res, False
 
         with open(uploadItemEx.full_path, 'rb') as src:
             fileObj = File(src)
@@ -188,12 +166,7 @@ class Crypto_file(AuditModel):
     @classmethod
     def get_action(cls, res, item):
         action = None
-        if isinstance(settings.FILES_STORE, dict):
-            exists = str(res.attfile) != ''
-            if exists is True:
-                exists = settings.SSH_CLIENTS.client(settings.FILES_STORE).exists(path=str(res.attfile))
-        else:
-            exists = os.path.exists(str(res.attfile))
+        exists = os.path.exists(str(res.attfile))
 
         if res.size is None or res.size == 0 or not exists:
             action = 'create'
