@@ -14,18 +14,20 @@ from isc_common.models.audit import AuditModel
 
 logger = logging.getLogger(__name__)
 
+
 class NonamedUserException(Exception):
     pass
 
+
 class AbstractUser(AbstractBaseUser, AuditModel):
     username_validator = UnicodeUsernameValidator()
 
-    birthday = DateField(blank=True, null=True)
-    first_name = NameField(verbose_name=_('имя'))
-    last_name = NameField(verbose_name=_('фамилия'))
-    middle_name = NameField(verbose_name=_('отчетво'))
-    usergroup = ManyToManyField(UserGroup, verbose_name=_('группы'))
-    username = CodeStrictField(verbose_name=_('логин'), unique=True, validators=[username_validator], error_messages={'unique': _("Такой пользователь уже существует."), }, )
+    birthday = DateField(blank = True, null = True)
+    first_name = NameField(verbose_name = 'имя')
+    last_name = NameField(verbose_name = 'фамилия')
+    middle_name = NameField(verbose_name = 'отчетво')
+    usergroup = ManyToManyField(UserGroup, verbose_name = 'группы')
+    username = CodeStrictField(verbose_name = 'логин', unique = True, validators = [username_validator], error_messages = {'unique': "Такой пользователь уже существует.", }, )
 
     @property
     def is_admin(self):
@@ -50,8 +52,8 @@ class AbstractUser(AbstractBaseUser, AuditModel):
     REQUIRED_FIELDS = ['email']
 
     class Meta:
-        verbose_name = _('пользователь')
-        verbose_name_plural = _('пользователи')
+        verbose_name = 'пользователь'
+        verbose_name_plural = 'пользователи'
         abstract = True
 
     def clean(self):
@@ -65,7 +67,7 @@ class AbstractUser(AbstractBaseUser, AuditModel):
                f'{self.middle_name.strip() if self.middle_name else ""}'
 
     @classmethod
-    def full_name(cls, first_name, middle_name, last_name, birthday=None, translit=False):
+    def full_name(cls, first_name, middle_name, last_name, birthday = None, translit = False):
         if first_name is None and middle_name is None and last_name is None:
             raise NonamedUserException('first_name is None and middle_name is None and last_name is None')
 
@@ -78,7 +80,7 @@ class AbstractUser(AbstractBaseUser, AuditModel):
         return res.strip()
 
     @classmethod
-    def short_name(cls, first_name, middle_name, last_name, translit=False):
+    def short_name(cls, first_name, middle_name, last_name, translit = False):
         from isc_common.models.audit import AuditModel
 
         if first_name is None and middle_name is None and last_name is None:
@@ -133,6 +135,6 @@ class AbstractUser(AbstractBaseUser, AuditModel):
     def user_short_name(self):
         return self.get_short_name
 
-    def email_user(self, subject, message, from_email=None, **kwargs):
+    def email_user(self, subject, message, from_email = None, **kwargs):
         """Send an email to this user."""
         send_mail(subject, message, from_email, [self.email], **kwargs)
