@@ -34,10 +34,7 @@ class UploadItem:
 
     @property
     def full_path(self):
-        if isinstance(settings.FILES_STORE, str):
-            return f'{get_tmp_dir(os.path.abspath(settings.FILES_STORE))}{os.sep}{self.stored_file_name}' if self.stored_file_name else None
-        else:
-            return f'{get_tmp_dir()}{os.sep}{self.stored_file_name}' if self.stored_file_name else None
+        return f'{get_tmp_dir(os.path.abspath(settings.FILES_STORE))}{os.sep}{self.stored_file_name}' if self.stored_file_name else None
 
     def getKey(self):
         return self.key.hex().upper()
@@ -100,21 +97,8 @@ class UploadItem:
         if not settings.FILES_STORE:
             raise Exception('Не задан FILES_STORE.')
 
-        if isinstance(settings.FILES_STORE, str):
-            if not os.path.exists(settings.FILES_STORE):
-                raise Exception(f'Заданный FILES_STORE : {settings.FILES_STORE} не существует.')
-        elif isinstance(settings.FILES_STORE, dict) and settings.FILES_STORE.get('mode') == SFTP:
-            if settings.FILES_STORE.get('PATH') is None:
-                raise Exception('FILES_STORE не содержит параметр PATH')
-
-            PATH = settings.FILES_STORE.get('PATH')
-            res = settings.SSH_CLIENTS.client(settings.FILES_STORE).exists(PATH)
-
-            if res is False:
-                raise Exception(f'Заданный FILES_STORE (SFTP) : {PATH} не существует.')
-
-        else:
-            raise Exception(FILES_STORE_UNKNOWN_TYPE)
+        if not os.path.exists(settings.FILES_STORE):
+            raise Exception(f'Заданный FILES_STORE : {settings.FILES_STORE} не существует.')
 
         if dictionary is not None and dictionary.get('key') is not None:
             self.key = dictionary.get('key')
