@@ -3,7 +3,7 @@ from django.utils.translation import gettext_lazy as _
 
 
 class CaptionField(CharField):
-    description = _("Наименованиме")
+    description = "Наименованиме"
 
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('max_length', 255)
