@@ -147,7 +147,7 @@ class DSRequest(RPCRequest):
                             self.set_user_data(user = httpHeaders.get('USER_ID'))
 
         elif request.method == "GET":
-            get_dict = dict(request.GET)
+            get_dict = request.GET.dict()
             self.json = get_dict
 
             if not self.json:
