@@ -8,6 +8,7 @@ import traceback
 from django.conf import settings
 from django.db.models import QuerySet, Model
 from django.forms import model_to_dict
+from isc_common.number import TryToInt
 from websocket import create_connection
 
 from isc_common import setAttr, Wrapper, user_name_anonim
@@ -242,8 +243,8 @@ class DSResponse(RPCResponse):
 
         request = DSRequest(request=request) if request else None
         self.dataSource = dataSource
-        self.endRow = request.endRow if request else None
-        self.startRow = request.startRow if request else None
+        self.endRow = TryToInt(request.endRow) if request else None
+        self.startRow = TryToInt(request.startRow) if request else None
         self.drawAheadRatio = request.drawAheadRatio if request else 1.2
         self.errors = errors
         self.invalidateCache = invalidateCache
