@@ -13,7 +13,7 @@ class Command(BaseCommand):
         return f'"{str}"'
 
     def handle(self, *args, **options):
-        for sequence in Pg_class.objects.filter(relkind='S'):
+        for sequence in Pg_class.objects.filter(relkind='S').order_by('relname'):
             with connection.cursor() as cursor:
                 seq_name = sequence.relname
                 table_name = seq_name[0:sequence.relname.rfind('_id_seq')]
@@ -22,8 +22,10 @@ class Command(BaseCommand):
                     row = cursor.fetchone()
                     id = row[0]
 
-                    if id:
+                    if isinstance(id, int):
                         cursor.execute(f'alter sequence {seq_name} restart with {id};')
+                        # logger.info(f'seq: {table_name}, id: {id}')
                         print(f'seq: {table_name}, id: {id}')
                 except Exception as e:
-                    print(e)
+                    pass
+                    # logger.error(e)
