@@ -8,7 +8,7 @@ from django.db import connection, transaction
 from django.db.models import Manager, QuerySet, Q, ForeignKey, BooleanField
 from django.db.models import Model
 from django.forms import model_to_dict
-from isc_common import delAttr, setAttr
+from isc_common import delAttr, setAttr, delAttr1
 from isc_common.bit import TurnBitOn, TurnBitOff, IsBitOnBool
 from isc_common.common import ONE_STAGE_ADDING, DELETE_ONE_STAGE, delete_image_refs
 from isc_common.common.functions import get_dict_only_model_field
@@ -423,7 +423,7 @@ class CommonQuerySet(QuerySet):
 
     def get_query(self, distinct_field_names, start, end, criteria, args, ob):
         if isinstance(distinct_field_names, tuple) or (isinstance(distinct_field_names, list)):
-            if self.alive_only == False:
+            if self.alive_only is False:
                 if start is not None and end is not None:
                     queryResult = super().filter(*args, criteria).distinct(*distinct_field_names)[start:end]
                 elif start is not None and end is None:
@@ -442,7 +442,7 @@ class CommonQuerySet(QuerySet):
                 else:
                     queryResult = super().filter(*args, criteria).filter(deleted_at__isnull = True).distinct(*distinct_field_names)
         else:
-            if self.alive_only == False:
+            if self.alive_only is False:
                 if start is not None and end is not None:
                     queryResult = super().order_by(*ob).filter(*args, criteria).distinct()[start:end]
                 elif start is not None and end is None:
@@ -466,12 +466,13 @@ class CommonQuerySet(QuerySet):
         json = kwargs.get('json')
 
         distinct_field_names = kwargs.get('distinct_field_names')
+
         end = kwargs.get('end')
         start = kwargs.get('start')
 
-        criteria = self.get_criteria(json = json)
-        # print(f'json: {json}')
-        # print(f'self.alive_only: {self.alive_only}')
+        delAttr(json, 'startRow')
+        delAttr(json, 'endRow')
+        criteria = self.get_criteria(json = delAttr1(json, 'alive_only'))
 
         ob = json.get("sortBy", []) if isinstance(json, dict) else []
 
@@ -510,11 +511,15 @@ class CommonQuerySet(QuerySet):
             if deleted is True:
                 setAttr(request.json, 'data', data)
 
-        self.alive_only = request.alive_only
+        if kwargs.get('alive_only') is not None:
+            self.alive_only = kwargs.get('alive_only')
+        else:
+            self.alive_only = request.alive_only
+
         self.enabledAll = request.enabledAll
         res = self.get_range_rows(
-            start = request.startRow,
-            end = request.endRow,
+            start = TryToInt(request.startRow),
+            end = TryToInt(request.endRow),
             function = function,
             distinct_field_names = distinct_field_names,
             json = request.json,
