@@ -17,10 +17,6 @@ class AuditModelExManager(AuditManager):
     def getRecord(cls, record):
         res = {
             'id': record.id,
-            'code': record.code,
-            'name': record.name,
-            'description': record.description,
-            'parent': record.parent.id if record.parent else None,
             'editing': record.editing,
             'deliting': record.deliting,
         }
@@ -31,7 +27,8 @@ class AuditModelExManager(AuditManager):
 
 
 class AuditModelEx(AuditModel):
-    creator = ForeignKeyProtect(User, related_name='AuditModelEx_creator')
+    creator = ForeignKeyProtect(User, related_name='+', null=True, blank=True)
+    editor = ForeignKeyProtect(User, related_name='+', null=True, blank=True)
     objects = AuditModelExManager()
 
     def __str__(self):
@@ -42,3 +39,4 @@ class AuditModelEx(AuditModel):
 
     class Meta:
         verbose_name = ' Расширенная AuditModel'
+        abstract = True
