@@ -60,18 +60,10 @@ class Common_UploadImage(DSResponse_UploadFile):
 
         if res is not None:
             attfile = make_REPLACE_FILE_PATH(str(res.attfile))
-
-            if isinstance(settings.FILES_STORE, str):
-                ex = os.path.exists(attfile)
-                if ex is False:
-                    delete_img_refs(old_id=res.id)
-                    res = None
-            else:
-                ssh_clients = settings.SSH_CLIENTS.client(settings.FILES_STORE)
-                ex = ssh_clients.exists(attfile)
-                if ex is False:
-                    delete_img_refs(old_id=res.id)
-                    res = None
+            ex = os.path.exists(attfile)
+            if ex is False:
+                delete_img_refs(old_id=res.id)
+                res = None
 
         if res is None:
             with TemporaryFile() as src:
@@ -98,12 +90,7 @@ class Common_UploadImage(DSResponse_UploadFile):
                         src.seek(0)
                         fileObj = File(src)
 
-                        if isinstance(settings.FILES_STORE, str):
-                            file_store = os.path.abspath(settings.FILES_STORE)
-                        elif isinstance(settings.FILES_STORE, dict) and settings.FILES_STORE.get('mode') == SFTP:
-                            file_store = settings.FILES_STORE.get('PATH')
-                        else:
-                            raise Exception(FILES_STORE_UNKNOWN_TYPE)
+                        file_store = os.path.abspath(settings.FILES_STORE)
 
                         res = Images.objects.create(
                             attfile=fileObj,
