@@ -1,8 +1,6 @@
 import logging
 
 from crypto.models.crypto_file import Crypto_file, CryptoManager, CryptoQuerySet
-from isc_common.fields.related import ForeignKeyCascade
-from tracker.models.messages import Messages
 
 logger = logging.getLogger(__name__)
 
@@ -26,7 +24,7 @@ class Messages_filesManager(CryptoManager):
         return res
 
     def get_queryset(self):
-        return Messages_filesQuerySet(self.model, using=self._db)
+        return Messages_filesQuerySet(self.model, using = self._db)
 
 
 class Messages_files(Crypto_file):
